import React, { useState } from "react";
import { StyleSheet } from "react-native";
import { View, Alert } from "react-native";
import { Button, Paragraph, Dialog, Portal } from "react-native-paper";
import { RadioButton, Text } from "react-native-paper";
import { Divider } from "react-native-paper";
import APIKit from "../APIkit";
import CustomActivityIndicator from "./CustomActivityIndicator";
import { toast500, toastError } from "../constants/toasts";

const CustomDialog = (props) => {
  const [value, setValue] = React.useState(1);
  const [showIndicator, setShowIndicator] = useState(false);
  const [resetCode, setResetCode] = useState(null);

  const updateUser = () => {
    let bodyFormData = new FormData();
    bodyFormData.append("email", props.email);
    bodyFormData.append("id", props.id);

    switch (value) {
      case 1:
        bodyFormData.append("denyAccess", true);
        break;
      case 2:
        bodyFormData.append("makeAdmin", true);
        break;
      case 3:
        bodyFormData.append("removeAdmin", true);
        break;
    }

    setShowIndicator(true);

    APIKit.post("/manageUsers", bodyFormData)
      .then(function (response) {
        setShowIndicator(false);
        if (response.data.status === 200) {
          props.showFeedback(response.data.message);
          props.getUsers();
          props.onCancel();
        } else {
          toastError("top", 3000, response.data.message); 
        }
      })
      .catch(function (response) {
        setShowIndicator(false);
        toast500(response.status); 
      });
  };

  const resetPassword = () => {
    let bodyFormData = new FormData();
    bodyFormData.append("id", props.id);

    setShowIndicator(true);

    APIKit.put("/manageUsers", bodyFormData)
      .then(function (response) {
        setShowIndicator(false);
        if (response.data.status === 200) {
          props.showFeedback(response.data.message);
          setResetCode(response.data.new_password);
        }
      })
      .catch(function (response) {
        setShowIndicator(false);
        toast500(response.status); 
      });
  };

  const createResetAlert = () =>
    Alert.alert(
      "Resetting password",
      "This is a temporary password!\n\nPlease have the affected user change their password after login!",
      [
        {
          text: "Cancel",
          onPress: () => console.log("Cancel Pressed"),
          style: "cancel",
        },
        { text: "OK", onPress: () => resetPassword() },
      ],
      { cancelable: false }
    );

  return (
    <View>
      <Portal>
        <Dialog visible={props.visible} onDismiss={props.onCancel}>
          <CustomActivityIndicator
            style={styles.activityIndicator}
            visible={showIndicator}
          />
          <Dialog.Title>Change Access Rights</Dialog.Title>
          <Divider />
          <Dialog.Content>
            <Paragraph>{props.email}</Paragraph>
            <Paragraph>
              Admin:{props.admin.toString()}, Accepted:
              {props.accepted.toString()}
            </Paragraph>
            <View>
              <RadioButton.Group
                onValueChange={(newValue) => setValue(newValue)}
                value={value}
              >
                <View style={styles.radioButton}>
                  <RadioButton value={1} />
                  <Text>Deny Access</Text>
                </View>
                <View style={styles.radioButton}>
                  <RadioButton value={2} />
                  <Text>Make Admin</Text>
                </View>
                <View style={styles.radioButton}>
                  <RadioButton value={3} />
                  <Text>Remove Admin</Text>
                </View>
              </RadioButton.Group>
            </View>
            <Divider />
            <View style={{ marginTop: 10 }}>
              <Button
                style={styles.resetButton}
                onPress={createResetAlert}
              >Reset Password</Button>
              {resetCode && <Text>Temporary password is: {resetCode}</Text>}
            </View>
          </Dialog.Content>
          <Dialog.Actions>
            <Button onPress={props.onCancel}>Cancel</Button>
            <Button onPress={updateUser}>Done</Button>
          </Dialog.Actions>
        </Dialog>
      </Portal>
    </View>
  );
};

export default CustomDialog;

const styles = StyleSheet.create({
  radioButton: {
    flexDirection: "row",
    alignItems: "center",
  },
  resetButton: {
    width: "70%",
  },
});
