import React, { useState, useEffect } from "react";
import { StyleSheet, View, SafeAreaView, FlatList } from "react-native";

import CustomButton from "../../components/CustomButton";
import APIKit from "../../APIkit";
import CustomActivityIndicator from "../../components/CustomActivityIndicator";
import ManageUser from "../../components/ManageUser";
import { toastError, toast500 } from "../../constants/toasts";

const ManageUsersScreen = ({ navigation }) => {
  const [users, setUsers] = useState([]);
  const [showIndicator, setShowIndicator] = useState(false);

  const renderItem = ({ item }) => (
    <ManageUser
      email={item.email}
      id={item.id}
      admin={item.admin}
      accepted={item.accepted}
      getUsers={getUsers}
    />
  );

  const getUsers = () => {
    setShowIndicator(true); 
    APIKit.get("/manageUsers")
      .then(function (response) {
        setShowIndicator(false); 
        if (response.data.status === 200) {
          setUsers(response.data.users);
        } else {
          toastError("top", 3000, response.data.message); 
        }
      })
      .catch(function (response) {
        setShowIndicator(false);
        toast500(response.status); 
      });
  };

  // for navigation on android to work
  useEffect(() => {
    getUsers();
    navigation.addListener('beforeRemove', (e) => {
      e.preventDefault();
      navigation.navigate("Profile");
    });
  }, []);

  return (
    <SafeAreaView style={{ flex: 1, alignItems: "stretch", marginTop: 15 }}>
      <CustomActivityIndicator style={styles.activityIndicator} visible={showIndicator} />
      <FlatList
        data={users}
        renderItem={renderItem}
        keyExtractor={(item) => item.id.toString()}
      />
      <View style={{ flex: 1 }}>
        <CustomButton
          style={styles.button}
          mode="contained"
          title="Done"
          onPress={() => navigation.navigate("Profile")}
        />
      </View>
    </SafeAreaView>
  );
};

export default ManageUsersScreen;

const styles = StyleSheet.create({
  button: {
    width: "40%",
    alignSelf: "center",
    marginTop: 20,
  },
});
