import React, { useEffect, useState } from "react";
import {
  StyleSheet,
  View,
  FlatList,
  SafeAreaView,
} from "react-native";

import CustomButton from "../../components/CustomButton";
import APIKit from "../../APIkit";
import CustomActivityIndicator from "../../components/CustomActivityIndicator";
import PendingUser from "../../components/PendingUser";
import { toast500, toastError } from "../../constants/toasts";

const PendingUsersScreen = ({ navigation }) => {
  const [pendingUsers, setPendingUsers] = useState([]);
  const [showIndicator, setShowIndicator] = useState(false);

  const renderItem = ({ item }) => (
    <PendingUser
      email={item.email}
      id={item.id}
      getPendingUsers={getPendingUsers}
    />
  );

  const getPendingUsers = () => {
    setShowIndicator(true);
    APIKit.get("/pendingUsers")
      .then(function (response) {
        setShowIndicator(false);
        if (response.data.status === 200) {
          setPendingUsers(response.data.users);
        } else {
          toastError("top", 3000, response.data.message); 
        }
      })
      .catch(function (response) {
        setShowIndicator(false);
        toast500(response.status); 
      });
  };

  useEffect(() => {
    getPendingUsers();
    navigation.addListener('beforeRemove', (e) => {
      e.preventDefault();
      navigation.navigate("Profile");
    });

  }, []);

  return (
    <SafeAreaView style={{ flex: 1, alignItems: "stretch" }}>
      <CustomActivityIndicator style={styles.activityIndicator} visible={showIndicator} />
      <FlatList
        data={pendingUsers}
        renderItem={renderItem}
        keyExtractor={(item) => item.id.toString()}
      />
      <View style={{ flex: 1 }}>
        <CustomButton
          style={styles.button}
          mode="contained"
          title="Done"
          onPress={() => navigation.navigate("Profile")}
        />
      </View>
    </SafeAreaView>
  );
};

export default PendingUsersScreen;

const styles = StyleSheet.create({
  button: {
    width: "40%",
    alignSelf: "center",
    marginTop: 20,
  },
});
